@@ -5,12 +5,13 @@ import typing as t
 import muffin
 from muffin.plugins import BasePlugin
 from peewee_migrate import Router
-from peewee_aio import Manager
+from peewee_aio.model import AIOModel
+from peewee_aio.manager import Manager, cached_property
 
 from .fields import JSONField, Choices
 
 
-__version__ = "0.0.3"
+__version__ = "0.0.5"
 __project__ = "muffin-peewee-aio"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -105,6 +106,22 @@ class Plugin(BasePlugin):
         """Disconnect from the database (close a pool and etc.)."""
         await self.manager.disconnect()
 
+    async def __aenter__(self) -> 'Plugin':
+        """Connect the database."""
+        manager = t.cast(Manager, self.manager)
+        await manager.aio_database.connect()
+        return self
+
+    async def __aexit__(self, *args):
+        """Disconnect the database."""
+        await self.manager.aio_database.disconnect()
+
+    @cached_property
+    def Model(self) -> AIOModel:
+        """Generate base async model class."""
+        manager = t.cast(Manager, self.manager)
+        return manager.Model
+
     def __getattr__(self, name: str) -> t.Any:
         """Proxy attrs to self database."""
         return getattr(self.manager, name)
